@@ -21,13 +21,13 @@ def assemble(lines):
 
     # simple label pass
     labels = {}
-    current_address = 0
+    current_address = 1
     for line in tokenized_lines:
         tokens, rest = line
         for token in tokens:
             token_type, value = token
             if token_type == 'label':
-                labels[value] = current_address + 1
+                labels[value] = current_address
 
             elif token_type == 'operator':
                 current_address += 1
@@ -64,10 +64,10 @@ def assemble(lines):
                     instruction = value.lower()
 
                     # Three params
-                    if instruction in ['add', 'addi', 'and', 'andi',
+                    if instruction in ['add', 'addi', 'and', 'andi', 'ld',
                                        'mul', 'muli', 'or', 'ori', 'sll',
                                        'slli', 'sra', 'srai', 'srl', 'srli',
-                                       'sub', 'subi', 'xor', 'xori']:
+                                       'st', 'sub', 'subi', 'xor', 'xori']:
                         _, a = tokens.next()
                         _, b = tokens.next()
                         _, c = tokens.next()
@@ -75,8 +75,8 @@ def assemble(lines):
                             value.capitalize()](a, b, c)
 
                     # Two params
-                    elif instruction in ['call', 'jmp', 'ld', 'ldi',
-                                         'st', 'sti', 'stg', 'cmp',
+                    elif instruction in ['call', 'jmp', 'ldi',
+                                         'sti', 'stg', 'cmp',
                                          'mv', 'neg', 'not']:
                         _, a = tokens.next()
                         maybe_label, b = tokens.next()
