@@ -102,9 +102,10 @@ class Jmp(RI):
 class Ld(RRI):
     opcode = 0b0000
 
-    def __init__(self, rd, rs):
+    def __init__(self, rd, rs, immediate):
         self.rd = rd
         self.rs = rs
+        self.immediate
 
 
 class Ldi(RI):
@@ -114,9 +115,10 @@ class Ldi(RI):
 class St(RRI):
     opcode = 0b0001
 
-    def __init__(self, rd, rs):
+    def __init__(self, rd, rs, immediate):
         self.rd = rd
         self.rs = rs
+        self.immediate = immediate
 
 
 class Sti(RI):
